@@ -6,6 +6,7 @@ import pytz
 import traceback
 import zope.component
 
+from certbot import crypto_util
 from certbot import errors
 from certbot import interfaces
 from certbot import ocsp
@@ -73,6 +74,7 @@ def certificates(config):
     for renewal_file in storage.renewal_conf_files(config):
         try:
             renewal_candidate = storage.RenewableCert(renewal_file, config)
+            crypto_util.verify_renewable_cert(renewal_candidate)
             parsed_certs.append(renewal_candidate)
         except Exception as e:  # pylint: disable=broad-except
             logger.warning("Renewal configuration file %s produced an "
@@ -100,7 +102,10 @@ def lineage_for_certname(cli_config, certname):
     configs_dir = cli_config.renewal_configs_dir
     # Verify the directory is there
     util.make_or_verify_dir(configs_dir, mode=0o755, uid=os.geteuid())
-    renewal_file = storage.renewal_file_for_certname(cli_config, certname)
+    try:
+        renewal_file = storage.renewal_file_for_certname(cli_config, certname)
+    except errors.CertStorageError:
+        return None
     try:
         return storage.RenewableCert(renewal_file, cli_config)
     except (errors.CertStorageError, IOError):
