@@ -18,11 +18,14 @@ from certbot.storage import ALL_FOUR
 from certbot.tests import storage_test
 from certbot.tests import util as test_util
 
-class BaseCertManagerTest(unittest.TestCase):
+from certbot.tests.util import TempDirTestCase
+
+
+class BaseCertManagerTest(TempDirTestCase):
     """Base class for setting up Cert Manager tests.
     """
     def setUp(self):
-        self.tempdir = tempfile.mkdtemp()
+        super(BaseCertManagerTest, self).setUp()
 
         os.makedirs(os.path.join(self.tempdir, "renewal"))
 
@@ -68,9 +71,6 @@ class BaseCertManagerTest(unittest.TestCase):
         config.write()
         return config
 
-    def tearDown(self):
-        shutil.rmtree(self.tempdir)
-
 
 class UpdateLiveSymlinksTest(BaseCertManagerTest):
     """Tests for certbot.cert_manager.update_live_symlinks
@@ -149,12 +149,14 @@ class CertificatesTest(BaseCertManagerTest):
         self.assertFalse(mock_utility.notification.called)
         self.assertTrue(mock_logger.warning.called) #pylint: disable=no-member
 
+    @mock.patch('certbot.crypto_util.verify_renewable_cert')
     @mock.patch('certbot.cert_manager.logger')
     @test_util.patch_get_utility()
     @mock.patch("certbot.storage.RenewableCert")
     @mock.patch('certbot.cert_manager._report_human_readable')
     def test_certificates_parse_success(self, mock_report, mock_renewable_cert,
-        mock_utility, mock_logger):
+        mock_utility, mock_logger, mock_verifier):
+        mock_verifier.return_value = None
         mock_report.return_value = ""
         self._certificates(self.cli_config)
         self.assertFalse(mock_logger.warning.called) #pylint: disable=no-member
@@ -290,6 +292,16 @@ class LineageForCertnameTest(BaseCertManagerTest):
             None)
         self.assertTrue(mock_make_or_verify_dir.called)
 
+    @mock.patch('certbot.util.make_or_verify_dir')
+    @mock.patch('certbot.storage.renewal_file_for_certname')
+    def test_no_renewal_file(self, mock_renewal_conf_file,
+        mock_make_or_verify_dir):
+        mock_renewal_conf_file.side_effect = errors.CertStorageError()
+        from certbot import cert_manager
+        self.assertEqual(cert_manager.lineage_for_certname(self.cli_config, "example.com"),
+            None)
+        self.assertTrue(mock_make_or_verify_dir.called)
+
 
 class DomainsForCertnameTest(BaseCertManagerTest):
     """Tests for certbot.cert_manager.domains_for_certname"""
@@ -427,9 +439,6 @@ class DuplicativeCertsTest(storage_test.BaseRenewableCertTest):
         self.config.write()
         self._write_out_ex_kinds()
 
-    def tearDown(self):
-        shutil.rmtree(self.tempdir)
-
     @mock.patch('certbot.util.make_or_verify_dir')
     def test_find_duplicative_names(self, unused_makedir):
         from certbot.cert_manager import find_duplicative_certs
