@@ -388,6 +388,7 @@ class AddDeprecatedArgumentTest(unittest.TestCase):
         with mock.patch("certbot.util.configargparse") as mock_configargparse:
             mock_configargparse.ACTION_TYPES_THAT_DONT_NEED_A_VALUE = typ()
             self._call("--old-option", 1)
+            self._call("--old-option2", 2)
         self.assertEqual(
             len(mock_configargparse.ACTION_TYPES_THAT_DONT_NEED_A_VALUE), 1)
 
@@ -419,6 +420,13 @@ class EnforceLeValidity(unittest.TestCase):
     def test_valid_domain(self):
         self.assertEqual(self._call(u"example.com"), u"example.com")
 
+    def test_input_with_scheme(self):
+        self.assertRaises(errors.ConfigurationError, self._call, u"http://example.com")
+        self.assertRaises(errors.ConfigurationError, self._call, u"https://example.com")
+
+    def test_valid_input_with_scheme_name(self):
+        self.assertEqual(self._call(u"http.example.com"), u"http.example.com")
+
 
 class EnforceDomainSanityTest(unittest.TestCase):
     """Test enforce_domain_sanity."""
